#
# File: OP/Enum/StatType.pm
#
# Copyright (c) 2009 TiVo Inc.
#
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Common Public License v1.0
# which accompanies this distribution, and is available at
# http://opensource.org/licenses/cpl1.0.txt
#
package OP::Enum::StatType;

use OP::Enum qw| Gauge Counter Derivative |;

=head1 NAME

OP::Enum::StatType - Series statistic type enumeration

=head1 DESCRIPTION

=head1 SYNOPSIS

=head1 CONSTANTS

=over 4

=back

=head1 SEE ALSO

L<OP::Enum>, L<OP::Persistence>

This file is part of L<OP>.

=head1 REVISION

$Id: //depotit/tools/source/snitchd-0.20/lib/OP/Enum/StatType.pm#2 $

=cut

1;
